==> haskell-blaze-markup-0.7.1.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.1.1
id: blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
key: blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
abi: 6afa1eea9cadfbbfae55ebb5d20990f2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/blaze-markup-0.7.1.1
hs-libraries: HSblaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.7.1.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.1.1
id: blaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX
key: blaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
abi: a0f90063066c575fdff4d0f19279f24f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/blaze-markup-0.7.1.1
hs-libraries: HSblaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S
    bytestring-0.10.8.1 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
